<table style="width: 100%; margin: 5px 20px; border-collapse: collapse;">
    <tr>
      <!-- Logo izquierdo -->
      <td style="width: 20%; text-align: left;">
        <img src="data:image/png;base64,{{ logo_unp }}" alt="Logo UNP" style="height: 80px;">
      </td>
  
      <!-- Título centrado -->
      <td style="width: 40%; text-align: center;">
        <p style="font-size: 18px; color: #303d50; font-weight: 700; margin: 0;">{{ titulo1 }}</p>
        <p style="font-size: 18px; color: #303d50; font-weight: 700; margin: 0;">{{ titulo2 }}</p>
        <p style="font-size: 18px; color: #303d50; font-weight: 700; margin: 0;">{{ titulo3 }}</p>
      </td>
      
  
      <!-- Logo derecho -->
      <td style="width: 20%; padding: 0 0 0 80px; text-align: left;">
        <img src="data:image/jpeg;base64,{{ logo_min }}" alt="Logo MinInterior" style="height: 80px;">
      </td>
    </tr>
  </table>
  