<table>
    <tr>
        <td class="celda-u" style="width: 980px">
            <p style=" font-size: 11px; color: #002857;  text-align:justify ; margin: 0px">
                De conformidad con el numeral 1° del artículo 74 de la Ley 1437 de 2011, frente a la presente resolución procede el RECURSO DE REPOSICIÓN,
                el cual deberá interponerse dentro de los diez (10) días hábiles siguientes a la notificación del acto administrativo,
                 señalando expresamente los motivos de inconformidad y aportando las pruebas que se pretende hacer valer.
                (Artículos 76 y 77 de la norma ibidem).
            </p>
        </td>
    </tr>
</table>
<div class="subtitulo">
    <i class="fa-solid fa-file"></i>
    <p style=" font-size: 16px; color: #002857; font-weight: 700; text-align: left; margin: 0px">
        {{numeracion}}Términos y Condiciones de la Política de Tratamiento de Datos Personales de la UNP *
    </p>
</div>
<div class="especial" style=" width: 96%; margin-top: 10px;">
    <table>
        <tr>
            <td class="celda-i" style="width: 46px;">
                {% if consentimiento.acepta_tdpersonales %}
                <i class="fa-regular fa-square-check" style="font-size: 30px; color: #ccc;"></i>
                {% else %}
                <i class="fa-regular fa-square" style="font-size: 30px; color: #ccc;"></i>
                {% endif %}
                
            </td>
            <td class="celda-d" style="width: 944px">
                <p style="font-size: 15px; color: #002857">
                    Manifiesto y acepto que conozco los términos y condiciones de la <b>Política de Tratamiento y
                        Protección de Datos
                        Personales de la UNP</b> y autorizo el uso de mis datos personales para recibir
                    comunicaciones y/o notificaciones
                    sobre los trámites relacionados con las actividades misionales adelantadas por la Entidad.
                </p>
            </td>
        </tr>
    </table>
</div>