<table style="width: 100%; margin-top: 15px;">
    <tr>
        <!-- Firma izquierda -->
        <td style="width: 50%; padding-left: 20px; text-align: left; vertical-align: top;">
            <label style="font-weight: bold; color: #002857; display: block; margin-bottom: 4px;">
                Firma de la persona a evaluar o representante legal
            </label>
            <div style="background-color: #f2f2f2; height: 40px; width: 100%; margin-bottom: 8px;"></div>
            <label style="color: #002857;">
                <strong>{{ nombrei }}</strong>
                
            </label>
            <label style="color: #002857;">
                <strong>{{ documentoi }}</strong>
            </label>

        </td>

        <!-- Firma derecha -->
        <td style="width: 50%; padding-left: 20px; text-align: left; vertical-align: top;">
            <label style="font-weight: bold; color: #002857; display: block; margin-bottom: 4px;">
                Firma del psicólogo(a) - UNP
            </label>
            <div style="background-color: #f2f2f2; height: 50px; width: 95%; margin-bottom: 8px;"></div>
            <label style="color: #002857;">
                <strong>{{ nombred }}</strong><br>
                <strong>{{ documentod }}</strong><br>
                <strong>{{ tarjetad }}</strong><br>
            </label>
        </td>
    </tr>
</table>